# Fluffy Funicular
Experimental envelope and body profile validator.

Cascaded shape schema validation via russian doll design? Maybe.

Practical validation should expose the most convenient structure for stacked profiles (always adding not subtracting).

Read the source, Lucy!
